// ~/.{librewolf,var/app/io.gitlab.librewolf-community/.librewolf}/librewolf.overrides.cfg

// LibreWolf override configuration, begins with samples from
// https://librewolf.net/docs/settings/
// Also incorporates some of https://aminda.eu/browser-extensions#firefox-aboutconfig

// -----
// I often need to refer to these options which aren't yet remembered by heart

// Note to self on disabling protection of Mozilla pages. This may be a
// LibreWolf default so thus commented:
// via https://www.ghacks.net/2017/10/27/how-to-enable-firefox-webextensions-on-mozilla-websites/
//pref("extensions.webextensions.restrictedDomains", "");
//pref("privacy.resistFingerprinting.block_mozAddonManage", true);

// Block cookie banners. Warning: may result to auto-accepting cookies.
// https://www.ghacks.net/2022/12/24/configure-firefox-to-reject-cookie-banners-automatically/
pref("cookiebanners.service.mode", 2);
pref("cookiebanners.service.mode.privateBrowsing", 2);
pref("cookiebanners.bannerClicking.enabled", true);

// https://globalprivacycontrol.org/ the successor of DNT
pref("privacy.globalprivacycontrol.enabled", true);
pref("privacy.globalprivacycontrol.functionality.enabled", true);
// and DNT itself
pref("privacy.donottrackheader.enabled", true);
pref("privacy.donottrackheader.value", 1);

// -----

// I would like to use this, but forced light mode is a dealbreaker
// (floaters), UTC makes Mobilizon difficult, Privacy Badger blocks 3rd party
// canvas and I want to appear as a Finnish Linux user rather than English
// Windows NT one (telemetry, voting vs spying).
pref("privacy.resistFingerprinting", true);
// Or I could excempt things from it? Other than it not overriding timezone.
pref("privacy.resistFingerprinting.testGranularityMask", 4);
pref(
	"privacy.resistFingerprinting.exemptedDomains",
	"jarkkaa.fi,*.element.io,*.google.com,*.pikaviestin.fi,*.envs.net,*.wikimedia.org,*.wikipedia.org,*.duckduckgo.com,*.blesmrt.net,*.piraatit.fi,*.piraattipuolue.fi,*.apple.com,*.op.fi,*.s-pankki.fi,*.revolut.com,*.n26.com",
);

// Enable letterboxing
pref("privacy.resistFingerprinting.letterboxing", true);

// Enable Firefox accounts
pref("identity.fxaccounts.enabled", true);

// Settings on what to clear on quit
// - Goal: let Element Web & co stay logged in
pref("privacy.clearOnShutdown.cache", false);
pref("privacy.clearOnShutdown.cookies", false);
pref("privacy.clearOnShutdown.history", false);
pref("privacy.clearOnShutdown.offlineApps", false);
pref("privacy.clearOnShutdown.openWindows", false);
pref("privacy.clearOnShutdown.sessions", false);
pref("privacy.clearOnShutdown.siteSettings", false);

// Don't resume from crash (SSD)
pref("browser.sessionstore.resume_from_crash", false);

// Stricter autoplay
pref("media.autoplay.blocking_policy", 2);

// No corporate CA MITM
pref("security.certerrors.mitm.auto_enable_enterprise_roots", false);

// Decrease animations
pref("image.animation_mode", "once");

// Punycode
pref("network.IDN_show_punycode", true);

// Enforce reader mode enabling?
pref("reader.parse-on-load.force-enabled", true);

// TRR & ECH
// Mode 2 allows fallback to system resolver, 3 is TTR-only
//pref("network.trr.mode", 2);
pref("network.trr.mode", 3);
pref("network.trr.early-AAAA", true);
pref("network.trr.uri", "https://dns0.eu");
//pref("network.trr.uri", "https://dns.adguard-dns.com/dns-query");
// NOTE: ECH requires TRR, so mode 2 may not use it.
pref("network.trr.disable-ECS", false);
pref("network.dns.echconfig.enabled", true);
pref("network.dns.use_https_rr_as_altsvc", true);
pref("network.trr.exclude-etc-hosts", false);
pref(
	"network.trr.excluded-domains",
	"http.badssl.com,norwegianwifi.com,mywifiext.net,tplinkrepeater.net,router.asus.com",
);

// Default UI scale
pref("layout.css.devPixelsPerPx", "1.5");

// Keep cache on both disk & memory. This is required for
// https://github.com/JimmXinu/FanFicFare/wiki/BrowserCacheFeature
pref("browser.cache.disk.enable", true);
pref("browser.cache.memory.enable", true);

// Start from homepage, don't restore the previous session (excluding pinned tabs)'
pref("browser.startup.page", 1);
// Simplified DDG experience without prompts for extension and all
pref("browser.startup.homepage", "https://start.duckduckgo.com");

// vim: filetype=javascript
